summaryrefslogtreecommitdiff
path: root/app/assets/javascripts/registry/settings/store/state.js
diff options
context:
space:
mode:
Diffstat (limited to 'app/assets/javascripts/registry/settings/store/state.js')
-rw-r--r--app/assets/javascripts/registry/settings/store/state.js16
1 files changed, 12 insertions, 4 deletions
diff --git a/app/assets/javascripts/registry/settings/store/state.js b/app/assets/javascripts/registry/settings/store/state.js
index 582e18e5465..fccc0991c1c 100644
--- a/app/assets/javascripts/registry/settings/store/state.js
+++ b/app/assets/javascripts/registry/settings/store/state.js
@@ -8,9 +8,17 @@ export default () => ({
*/
isLoading: false,
/*
* Boolean to determine if the user is allowed to interact with the form
*/
- isDisabled: false,
+ isAdmin: false,
+ /*
+ * String containing the full path to the admin config page for CI/CD
+ */
+ adminSettingsPath: '',
+ /*
+ * Boolean to determine if project created before 12.8 can use this feature
+ */
+ enableHistoricEntries: false,
/*
* This contains the data shown and manipulated in the UI
* Has the following structure:
@@ -24,9 +32,9 @@ export default () => ({
*/
settings: {},
/*
- * Same structure as settings, above but Frozen object and used only in case the user clicks 'cancel'
+ * Same structure as settings, above but Frozen object and used only in case the user clicks 'cancel', initialized to null
*/
- original: {},
+ original: null,
/*
* Contains the options used to populate the form selects
*/
@@ -8,9 +8,17 @@ export default () => ({
isLoading: false,
/*
- * Boolean to determine if the user is allowed to interact with the form
+ * Boolean to determine if the user is an admin
*/